@@ -1,44 +1,26 @@
 import path from 'path';
-import {existsSync, watch} from 'fs';
+import {existsSync} from 'fs';
 import {base64Decode} from '../libs_drpy/crypto-util.js';
-import * as drpy from '../libs/drpyS.js';
 import {ENV} from "../utils/env.js";
 import {validatePwd} from "../utils/api_validate.js";
+import {startJsonWatcher, getApiEngine} from "../utils/api_helper.js";
+import * as drpyS from '../libs/drpyS.js';
+import drpy2 from '../libs/drpy2.js';
+import hipy from '../libs/hipy.js';
+import xbpq from '../libs/xbpq.js';
+import catvod from '../libs/catvod.js';
 
-//添加JSON文件监听  
-let jsonWatcher = null;
-let debounceTimers = new Map(); // 防抖计时器
-function startJsonWatcher(jsonDir) {
-    if (process.env.NODE_ENV !== 'development') return;
-
-    try {
-        jsonWatcher = watch(jsonDir, {recursive: true}, (eventType, filename) => {
-            if (filename && filename.endsWith('.json')) {
-                // 清除之前的计时器  
-                if (debounceTimers.has(filename)) {
-                    clearTimeout(debounceTimers.get(filename));
-                }
-
-                // 设置新的防抖计时器  
-                const timer = setTimeout(() => {
-                    console.log(`${filename}文件已${eventType}，即将清除所有模块缓存`);
-                    drpy.clearAllCache();
-                    debounceTimers.delete(filename);
-                }, 100); // 100ms防抖延迟  
-
-                debounceTimers.set(filename, timer);
-            }
-        });
-
-        console.log(`start json file hot reload success，listening path: ${jsonDir}`);
-    } catch (error) {
-        console.error('start json file listening failed with error:', error);
-    }
-}
+const ENGINES = {
+    drpyS,
+    drpy2,
+    hipy,
+    xbpq,
+    catvod,
+};
 
 export default (fastify, options, done) => {
     // 启动JSON监听  
-    startJsonWatcher(options.jsonDir);
+    startJsonWatcher(ENGINES, options.jsonDir);
 
     // 动态加载模块并根据 query 执行不同逻辑
     fastify.route({
@@ -50,22 +32,22 @@ export default (fastify, options, done) => {
         },
         handler: async (request, reply) => {
             const moduleName = request.params.module;
-            const modulePath = path.join(options.jsDir, `${moduleName}.js`);
+            const method = request.method.toUpperCase();
+            // 根据请求方法选择参数来源
+            const query = method === 'GET' ? request.query : request.body;
+            let {apiEngine, moduleDir, _ext, modulePath} = getApiEngine(ENGINES, moduleName, query, options);
             if (!existsSync(modulePath)) {
                 reply.status(404).send({error: `Module ${moduleName} not found`});
                 return;
             }
-            const method = request.method.toUpperCase();
-            // 根据请求方法选择参数来源
-            const query = method === 'GET' ? request.query : request.body;
+
             const moduleExt = query.extend || '';
             // console.log('moduleExt:', typeof moduleExt, moduleExt);
-            const protocol = request.protocol;
+            const protocol = request.headers['x-forwarded-proto'] || (request.socket.encrypted ? 'https' : 'http');
             const hostname = request.hostname;
             // const proxyUrl = `${protocol}://${hostname}${request.url}`.split('?')[0].replace('/api/', '/proxy/') + '/?do=js';
             // const proxyUrl = `${protocol}://${hostname}/proxy/${moduleName}/?do=js`;
             // console.log('proxyUrl:', proxyUrl);
-
             const publicUrl = `${protocol}://${hostname}/public/`;
             const jsonUrl = `${protocol}://${hostname}/json/`;
             const httpUrl = `${protocol}://${hostname}/http`;
@@ -95,12 +77,12 @@ export default (fastify, options, done) => {
 
             const env = getEnv(moduleName);
             env.getRule = async function (_moduleName) {
-                const _modulePath = path.join(options.jsDir, `${_moduleName}.js`);
+                const _modulePath = path.join(moduleDir, `${_moduleName}${_ext}`);
                 if (!existsSync(_modulePath)) {
                     return null;
                 }
                 const _env = getEnv(_moduleName);
-                const RULE = await drpy.getRule(_modulePath, _env);
+                const RULE = await apiEngine.getRule(_modulePath, _env);
                 RULE.callRuleFn = async function (_method, _args) {
                     let invokeMethod = null;
                     switch (_method) {
@@ -136,7 +118,7 @@ export default (fastify, options, done) => {
                             return await RULE[_method]
                         }
                     }
-                    return await drpy[invokeMethod](_modulePath, _env, ..._args)
+                    return await apiEngine[invokeMethod](_modulePath, _env, ..._args)
                 };
                 return RULE
             };
@@ -146,7 +128,7 @@ export default (fastify, options, done) => {
                 if ('play' in query) {
                     // 处理播放逻辑
                     // console.log('play query:', query);
-                    const result = await drpy.play(modulePath, env, query.flag, query.play);
+                    const result = await apiEngine.play(modulePath, env, query.flag, query.play);
                     return reply.send(result);
                 }
 
@@ -162,7 +144,7 @@ export default (fastify, options, done) => {
                         }
                     }
                     // 分类逻辑
-                    const result = await drpy.cate(modulePath, env, query.t, pg, 1, extend);
+                    const result = await apiEngine.cate(modulePath, env, query.t, pg, 1, extend);
                     return reply.send(result);
                 }
 
@@ -171,13 +153,13 @@ export default (fastify, options, done) => {
                         fastify.log.info(`[${moduleName}] 二级已接收post数据: ${query.ids}`);
                     }
                     // 详情逻辑
-                    const result = await drpy.detail(modulePath, env, query.ids.split(','));
+                    const result = await apiEngine.detail(modulePath, env, query.ids.split(','));
                     return reply.send(result);
                 }
 
                 if ('ac' in query && 'action' in query) {
                     // 处理动作逻辑
-                    const result = await drpy.action(modulePath, env, query.action, query.value);
+                    const result = await apiEngine.action(modulePath, env, query.action, query.value);
                     return reply.send(result);
                 }
 
@@ -185,13 +167,13 @@ export default (fastify, options, done) => {
                 if ('wd' in query) {
                     // 搜索逻辑
                     const quick = 'quick' in query ? query.quick : 0;
-                    const result = await drpy.search(modulePath, env, query.wd, quick, pg);
+                    const result = await apiEngine.search(modulePath, env, query.wd, quick, pg);
                     return reply.send(result);
                 }
 
                 if ('refresh' in query) {
                     // 强制刷新初始化逻辑
-                    const refreshedObject = await drpy.init(modulePath, env, true);
+                    const refreshedObject = await apiEngine.init(modulePath, env, true);
                     return reply.send(refreshedObject);
                 }
                 if (!('filter' in query)) {
@@ -199,8 +181,8 @@ export default (fastify, options, done) => {
                 }
                 // 默认逻辑，返回 home + homeVod 接口
                 const filter = 'filter' in query ? query.filter : 1;
-                const resultHome = await drpy.home(modulePath, env, filter);
-                const resultHomeVod = await drpy.homeVod(modulePath, env);
+                const resultHome = await apiEngine.home(modulePath, env, filter);
+                const resultHomeVod = await apiEngine.homeVod(modulePath, env);
                 let result = {
                     ...resultHome,
                     // list: resultHomeVod,
@@ -224,7 +206,8 @@ export default (fastify, options, done) => {
     fastify.get('/proxy/:module/*', async (request, reply) => {
         const moduleName = request.params.module;
         const query = request.query; // 获取 query 参数
-        const modulePath = path.join(options.jsDir, `${moduleName}.js`);
+
+        let {apiEngine, modulePath} = getApiEngine(ENGINES, moduleName, query, options);
         if (!existsSync(modulePath)) {
             reply.status(404).send({error: `Module ${moduleName} not found`});
             return;
@@ -234,7 +217,7 @@ export default (fastify, options, done) => {
         const rangeHeader = request.headers.range; // 获取客户端的 Range 请求头
 
         const moduleExt = query.extend || '';
-        const protocol = request.protocol;
+        const protocol = request.headers['x-forwarded-proto'] || (request.socket.encrypted ? 'https' : 'http');
         const hostname = request.hostname;
 
         const publicUrl = `${protocol}://${hostname}/public/`;
@@ -266,7 +249,7 @@ export default (fastify, options, done) => {
 
         const env = getEnv(moduleName);
         try {
-            const backRespList = await drpy.proxy(modulePath, env, query);
+            const backRespList = await apiEngine.proxy(modulePath, env, query);
             const statusCode = backRespList[0];
             const mediaType = backRespList[1] || 'application/octet-stream';
             let content = backRespList[2] || '';
@@ -339,7 +322,7 @@ export default (fastify, options, done) => {
             return reply.status(404).send({error: `解析 ${jxName} not found`});
         }
         const moduleExt = query.extend || '';
-        const protocol = request.protocol;
+        const protocol = request.headers['x-forwarded-proto'] || (request.socket.encrypted ? 'https' : 'http');
         const hostname = request.hostname;
 
         const publicUrl = `${protocol}://${hostname}/public/`;
@@ -371,7 +354,7 @@ export default (fastify, options, done) => {
 
         const env = getEnv('');
         try {
-            const backResp = await drpy.jx(jxPath, env, query);
+            const backResp = await drpyS.jx(jxPath, env, query);
             const statusCode = 200;
             const mediaType = 'application/json; charset=utf-8';
             if (typeof backResp === 'object') {
